@@ -50,17 +50,13 @@ class AlpacaLumnisTrader():
     Attributes
     ----------
     """
-    def __init__(self, binance_api_key, binance_secret_key, lumnis_api_key, coins, paper=True, time_frame="min"):
+    def __init__(self, binance_api_key, binance_secret_key, lumnis_api_key, factors, coins, paper=True, time_frame="min"):
 
         self.trading_client  = TradingClient(binance_api_key, binance_secret_key, paper=paper)
         self.tradable_assets = self.get_tradable_assets(coins)
         self.time_frame      = time_frame
         self.lumnisfactors   = LumnisFactors(lumnis_api_key)
-        self.factors         = ['macd'] #['rsi', 'vpin', 'order_imbalance', 'kyle_lambda_signed', 'amihuds_lambda',  'ffd', 'macd', 'obv', 'donchian','tsmom', 'bvc', 'hurst_exponent', 'anderson_darling_norm', 'anderson_darling_expon', 'shapiro_wilk','kolmogorov_smirnov', 'jarque_bera', 'agostino_k2']
-
-        #'hasbroucks_lambda', 'accumulation_distribution', 
-        for asset in self.tradable_assets:
-            print(asset.symbol)
+        self.factors         = factors
 
         self.tp              = 2
         self.sl              = 2
@@ -162,10 +158,10 @@ class AlpacaLumnisTrader():
         
         """
         raw_df  = self.history[symbol]
-        df      = standardize(raw_df, 10000)#['macd_250_500']
+        df      = standardize(raw_df, 10000)
 
         if strat == 'macd':
-            signal = (df['macd_250_500'].iloc[-1] > 2) * 1
+            signal = (df['vpin_500'].iloc[-1] > 2) * 1
             return signal
 
         return 0
